@@ -34,55 +34,71 @@
 #' @keywords manip
 #'
 #' @examples
-#' ## Get data with length measurements and some assigned ages
-#' data(WR79)
-#'
 #' ## First Example -- Even breaks for length categories
 #' WR1 <- WR79
-#' WR1$LCat <- lencat(WR1$len,w=5)                      # add length categories (width=5)
-#' WR1.age <- subset(WR1, !is.na(age))                  # isolate aged and unaged samples
+#' # add length categories (width=5)
+#' WR1$LCat <- lencat(WR1$len,w=5)
+#' # isolate aged and unaged samples
+#' WR1.age <- subset(WR1, !is.na(age))
 #' WR1.len <- subset(WR1, is.na(age))
-#' head(WR1.len)                                        # note no ages in unaged sample
-#' raw <- xtabs(~LCat+age,data=WR1.age)                 # create age-length key
+#' # note no ages in unaged sample
+#' head(WR1.len)
+#' # create age-length key
+#' raw <- xtabs(~LCat+age,data=WR1.age)
 #' ( WR1.key <- prop.table(raw, margin=1) )
-#' WR1.len <- alkIndivAge(WR1.key,age~len,data=WR1.len) # apply the age-length key
-#' head(WR1.len)                                        # now there are ages
-#' WR1.comb <- rbind(WR1.age, WR1.len)                  # combine orig age & new ages
-#' Summarize(len~age,data=WR1.comb,digits=2)            # mean length-at-age
-#' ( af <- xtabs(~age,data=WR1.comb) )                  # age frequency distribution
-#' ( ap <- prop.table(af) )                             # proportional age distribution
+#' # apply the age-length key
+#' WR1.len <- alkIndivAge(WR1.key,age~len,data=WR1.len)
+#' # now there are ages
+#' head(WR1.len)
+#' # combine orig age & new ages
+#' WR1.comb <- rbind(WR1.age, WR1.len)
+#' # mean length-at-age
+#' Summarize(len~age,data=WR1.comb,digits=2)
+#' # age frequency distribution
+#' ( af <- xtabs(~age,data=WR1.comb) )
+#' # proportional age distribution
+#' ( ap <- prop.table(af) )
 #'
 #' ## Second Example -- length sample does not have an age variable
 #' WR2 <- WR79
-#' WR2.age <- subset(WR2, !is.na(age))                  # isolate age and unaged samples
+#' # isolate age and unaged samples
+#' WR2.age <- subset(WR2, !is.na(age))
 #' WR2.len <- subset(WR2, is.na(age))
-#' WR2.len <- WR2.len[,-3]                              # remove age variable (for demo only)
-#' WR2.age$LCat <- lencat(WR2.age$len,w=5)              # add length categories to aged sample
-#' raw <- xtabs(~LCat+age,data=WR2.age)                 # create age-length key
+#' # remove age variable (for demo only)
+#' WR2.len <- WR2.len[,-3]
+#' # add length categories to aged sample
+#' WR2.age$LCat <- lencat(WR2.age$len,w=5)
+#' # create age-length key
+#' raw <- xtabs(~LCat+age,data=WR2.age)
 #' ( WR2.key <- prop.table(raw, margin=1) )
-#' WR2.len <- alkIndivAge(WR2.key,~len,data=WR2.len)    # apply the age-length key
-#' WR2.len$LCat <- lencat(WR2.len$len,w=5)              # add length cat to length sample
-#' head(WR2.len)                                        # now there are ages
-#' WR2.comb <- rbind(WR2.age, WR2.len)                  # combine orig age & new ages
+#' # apply the age-length key
+#' WR2.len <- alkIndivAge(WR2.key,~len,data=WR2.len)
+#' # add length cat to length sample
+#' WR2.len$LCat <- lencat(WR2.len$len,w=5)
+#' head(WR2.len)
+#' # combine orig age & new ages
+#' WR2.comb <- rbind(WR2.age, WR2.len)
 #' Summarize(len~age,data=WR2.comb,digits=2)
 #'
 #' ## Third Example -- Uneven breaks for length categories
 #' WR3 <- WR79
-#' brks <- c(seq(35,100,5),110,130)                     # set up uneven breaks
-#' WR3$LCat <- lencat(WR3$len,breaks=brks)              # add length categories (width=5)
-#' WR3.age <- subset(WR3, !is.na(age))                  # isolate aged and unaged samples
+#' # set up uneven breaks
+#' brks <- c(seq(35,100,5),110,130)
+#' WR3$LCat <- lencat(WR3$len,breaks=brks)
+#' WR3.age <- subset(WR3, !is.na(age))
 #' WR3.len <- subset(WR3, is.na(age))
-#' head(WR3.len)                                        # note no ages in length sample
-#' raw <- xtabs(~LCat+age,data=WR3.age)                 # create age-length key
+#' head(WR3.len)
+#' raw <- xtabs(~LCat+age,data=WR3.age)
 #' ( WR3.key <- prop.table(raw, margin=1) )
-#' WR3.len <- alkIndivAge(WR3.key,age~len,data=WR3.len,breaks=brks)  # apply the age-length key
-#' head(WR3.len)                                        # now there are ages
-#' WR3.comb <- rbind(WR3.age, WR3.len)                  # combine orig age & new ages
+#' WR3.len <- alkIndivAge(WR3.key,age~len,data=WR3.len,breaks=brks)
+#' head(WR3.len)
+#' WR3.comb <- rbind(WR3.age, WR3.len)
 #' Summarize(len~age,data=WR3.comb,digits=2)
 #'
 #' @export alkIndivAge
 #' @rdname alkIndivAge
-alkIndivAge <- function(key,formula,data,type=c("SR","CR"),breaks=NULL,seed=NULL) {
+alkIndivAge <- function(key,formula,data,type=c("SR","CR"),
+                        breaks=NULL,seed=NULL) {
   ## some checks
   type <- match.arg(type)
   key <- iCheckALK(key,only1=TRUE,remove0rows=TRUE)
@@ -91,13 +107,17 @@ alkIndivAge <- function(key,formula,data,type=c("SR","CR"),breaks=NULL,seed=NULL
   tmp <- iHndlFormula(formula,data,expNumE=1,expNumR=1)
   # handle differently depending on how many variables were in the formula
   if (tmp$vnum==1) {
-    if (!tmp$vclass %in% c("numeric","integer")) STOP("RHS ariable must be numeric.")
+    if (!tmp$vclass %in% c("numeric","integer"))
+      STOP("RHS ariable must be numeric.")
     ca <- "age"
     cl <- tmp$vname
   } else if (tmp$vnum==2) {
-    if (!tmp$metExpNumE) STOP("'alkIndivAge' must have only one RHS variable.")
-    if (!tmp$Eclass %in% c("numeric","integer")) STOP("RHS variable must be numeric.")
-    if (!tmp$Rclass %in% c("numeric","integer")) STOP("LHS variable must be numeric.")
+    if (!tmp$metExpNumE)
+      STOP("'alkIndivAge' must have only one RHS variable.")
+    if (!tmp$Eclass %in% c("numeric","integer"))
+      STOP("RHS variable must be numeric.")
+    if (!tmp$Rclass %in% c("numeric","integer"))
+      STOP("LHS variable must be numeric.")
     cl <- tmp$Enames
     ca <- tmp$Rname
   } else STOP("'formula' must have only one variable on LHS and RHS.")
@@ -116,9 +136,10 @@ alkIndivAge <- function(key,formula,data,type=c("SR","CR"),breaks=NULL,seed=NULL
          " or exclude fish of this length from your length sample.\n")
   }
   # Find the minimum width of the length categories so that this can be used
-  #   in the check for the maximum length without being too sensitive.  In other words
-  #   If the maximum observed length is greater than the maximum length category in
-  #   the ALK PLUS the minimum width of length categories then don't send the message.
+  #   in the check for the maximum length without being too sensitive.  In other
+  #   words, if the maximum observed length is greater than the maximum length
+  #    category in the ALK PLUS the minimum width of length categories then
+  #    don't send the message.
   min.w <- min(diff(da.len.cats))
   if (max(data[,cl],na.rm=TRUE)>(max(da.len.cats)+min.w)) {
     WARN("The maximum observed length in the length sample (",
@@ -130,9 +151,8 @@ alkIndivAge <- function(key,formula,data,type=c("SR","CR"),breaks=NULL,seed=NULL
   }
   # Create length categories var (TMPLCAT) for L sample
   if (is.null(breaks)) breaks <- da.len.cats
-  options(warn=-1)  # suppress warnings from lencat()
-  data <- lencat(stats::as.formula(paste("~",cl)),data=data,breaks=breaks,as.fact=FALSE,vname="TMPLCAT")
-  options(warn=1)
+  suppressWarnings(data <- lencat(stats::as.formula(paste("~",cl)),data=data,
+                                  breaks=breaks,as.fact=FALSE,vname="TMPLCAT"))
   # Find Vector of length cats present in L sample
   data.len.cats <- as.numeric(names(table(data$TMPLCAT)))                                  
   # Add variable for ages for L sample (initially NAs)
@@ -156,7 +176,7 @@ alkIndivAge <- function(key,formula,data,type=c("SR","CR"),breaks=NULL,seed=NULL
 ## Semi-random assignment internal function
 ##############################################################
 iAgeKey.SR <- function(key,age.cats,data,data.len.cats,ca) {                        
-  for (i in data.len.cats) {  ### Cycle through len categories in L sample                                              
+  for (i in data.len.cats) {  ### Cycle through len categories in L sample
     # Number in len interval from L sample
     len.n <- nrow(data[data$TMPLCAT==i,])
     # Conditional probability of age for len interval
@@ -177,7 +197,7 @@ iAgeKey.SR <- function(key,age.cats,data,data.len.cats,ca) {
     # Randomly mix up the ages vector
     if (length(ages)>1) { ages <- sample(ages,length(ages),replace=FALSE) }
     # Replace rows of age col w/ assigned ages
-    data[data$TMPLCAT==i,ca] <- ages                                               
+    data[data$TMPLCAT==i,ca] <- ages
   }
   data
 }
@@ -185,7 +205,7 @@ iAgeKey.SR <- function(key,age.cats,data,data.len.cats,ca) {
 ##############################################################
 ## Completely random assignment internal function
 ##############################################################
-iAgeKey.CR <- function(key,age.cats,data,ca) {                                    
+iAgeKey.CR <- function(key,age.cats,data,ca) {
   for (i in 1:dim(data)[1]) { #### Cycle through the fish
     # Conditional probability of age for length interval
     age.prob <- key[which(as.numeric(rownames(key))==data$TMPLCAT[i]),]
