@@ -24,7 +24,6 @@ test_that("srFuns() messages",{
 })
 
 test_that("srStarts() messages",{
-  data(CodNorwegian)
   CodNorwegian$fyear <- factor(CodNorwegian$year)
   ## Asked for a dynamicPlot, which now does not exist
   expect_warning(srStarts(recruits~stock,data=CodNorwegian,dynamicPlot=TRUE),
@@ -32,25 +31,33 @@ test_that("srStarts() messages",{
   ## wrong type
   expect_error(srStarts(type="Derek"))
   ## wrong parameterization choices
-  expect_error(srStarts(recruits~stock,data=CodNorwegian,type="BevertonHolt",param=0),
+  expect_error(srStarts(recruits~stock,data=CodNorwegian,
+                        type="BevertonHolt",param=0),
                "'param' must be in")
-  expect_error(srStarts(recruits~stock,data=CodNorwegian,type="BevertonHolt",param=5),
+  expect_error(srStarts(recruits~stock,data=CodNorwegian,
+                        type="BevertonHolt",param=5),
                "'param' must be in")
-  expect_error(srStarts(recruits~stock,data=CodNorwegian,type="BevertonHolt",param=c(1,3)),
+  expect_error(srStarts(recruits~stock,data=CodNorwegian,
+                        type="BevertonHolt",param=c(1,3)),
                "Only one 'param'")
   expect_error(srStarts(recruits~stock,data=CodNorwegian,type="Ricker",param=0),
                "'param' must be in")
   expect_error(srStarts(recruits~stock,data=CodNorwegian,type="Ricker",param=4),
                "'param' must be in")
-  expect_error(srStarts(recruits~stock,data=CodNorwegian,type="Ricker",param=c(1,3)),
+  expect_error(srStarts(recruits~stock,data=CodNorwegian,
+                        type="Ricker",param=c(1,3)),
                "Only one 'param'")
   ## wrong variables
   expect_error(srStarts(~stock,data=CodNorwegian),"with both LHS and RHS")
   expect_error(srStarts(stock~1,data=CodNorwegian),"with both LHS and RHS")
-  expect_error(srStarts(~stock+recruits,data=CodNorwegian),"only one LHS variable")
-  expect_error(srStarts(stock+recruits~1,data=CodNorwegian),"with both LHS and RHS")
-  expect_error(srStarts(stock~fyear,data=CodNorwegian),"RHS variable must be numeric")
-  expect_error(srStarts(fyear~recruits,data=CodNorwegian),"LHS variable must be numeric")
+  expect_error(srStarts(~stock+recruits,data=CodNorwegian),
+               "only one LHS variable")
+  expect_error(srStarts(stock+recruits~1,data=CodNorwegian),
+               "with both LHS and RHS")
+  expect_error(srStarts(stock~fyear,data=CodNorwegian),
+               "RHS variable must be numeric")
+  expect_error(srStarts(fyear~recruits,data=CodNorwegian),
+               "LHS variable must be numeric")
   expect_error(srStarts(stock~recruits+fyear,data=CodNorwegian),
                "only one LHS and only one RHS")
   ## Issues with fixed=
